/**
 * Defines the available types of fields that can be edited by the data editor,
 * set by a column's field type.
 */
export const FieldTypes = [
  'text',
  'image',
  'number',
  'dropdown',
  'multiselect',
  'toggle',
] as const

/**
 * Specifies the type of field for editing in the data editor.
 */
export type FieldType = typeof FieldTypes[number]

export interface Image {
  src: string
  alt?: string
}

/**
 * The structure of a column. Columns define the available fields to edit for every row
 * and control how they are edited.
 */
export interface Column {
  /** the name of the field; this represents the key in the columns record */
  name: string
  /** the type of the field; this controls how it is edited in the data editor */
  type: FieldType
  /** whether the field is secondary or not; if it is, it is hidden from the quick editing view in the data editor */
  secondary?: boolean
  /** options for the field; applies only to certain field types such as dropdowns */
  options?: any
}

/**
 * The structure of a Row. All rows at minimum should have a private _id field;
 * beyond that, it is simply a record of key-value pairs
 * where the key corresponds to a column by name
 */
export type Row = {
  _id: string
} & Record<string, string | any>

/**
 * The structure of an inventory. An inventory is simply a set of columns (fields) and rows (data),
 * where each row has key-value pairs where the keys correspond to a column by name,
 * and the columns define how the rows can be edited
 */
export interface Inventory {
  columns: Column[]
  rows: Row[]
}
